# Speed Benchmark Report

## Metadata

| Field | Value |
|-------|-------|
| **Run Date** | 2026-03-09 |
| **Total Duration** | 323.5s |
| **Requests** | 802 |

## Throughput

| Metric | Value |
|--------|-------|
| **Request Throughput** | 2.48 req/s |
| **Total Tokens/sec** | 4206.0 tok/s |
| **Generation Tokens/sec** | 1210.7 tok/s |

## Latency

| Metric | Value |
|--------|-------|
| **Avg TTFT** | 0.59s |
| **TTFT p50** | 2.50s |
| **TTFT p90** | 20.00s |

## Concurrency (during run)

| Metric | Value |
|--------|-------|
| **Peak Running** | 100 |
| **Peak Waiting** | 62 |
| **Peak KV Cache** | 81.5% |

## Token Statistics

| Metric | Value |
|--------|-------|
| **Prompt Tokens** | 969,139 |
| **Generation Tokens** | 391,720 |
| **Total Tokens** | 1,360,859 |
| **Avg Tokens/Request** | 1697 |

## Cache Efficiency

| Metric | Value |
|--------|-------|
| **Prefix Cache Hit Rate** | 63.5% |
| **Cached Tokens** | 615,584 |
| **Preemptions** | 0 |

## Accuracy (from eval)

| Metric | Value |
|--------|-------|
| **Overall Accuracy** | 92.9% |
| **Positive Accuracy** | 92.2% |
| **Negative Accuracy** | 93.9% |
